import { IconButton } from '@/shared/IconButton';
import { JSX } from 'react';
import { LayerDrawerLayerContextMenu } from '@/components/Map/Drawer/LayersDrawer/LayerDrawerLayerContextMenu.component';
import { useAppSelector } from '@/redux/hooks/useAppSelector';
import { hasPrivilegeToWriteProjectSelector } from '@/redux/user/user.selectors';

type LayersDrawerLayerActionsProps = {
  editLayer: () => void;
  removeLayer: () => void;
  isVisible: boolean;
  isActive: boolean;
  toggleVisibility: () => void;
  toggleActiveLayer: (value: boolean) => void;
  addImage: () => void;
  addText: () => void;
};

export const LayersDrawerLayerActions = ({
  editLayer,
  removeLayer,
  isVisible,
  isActive,
  toggleVisibility,
  toggleActiveLayer,
  addImage,
  addText,
}: LayersDrawerLayerActionsProps): JSX.Element => {
  const hasPrivilegeToWriteProject = useAppSelector(hasPrivilegeToWriteProjectSelector);

  return (
    <div className="flex gap-2">
      <IconButton
        icon={isVisible ? 'eye' : 'crossed-eye'}
        title="Switch visibility"
        className="h-auto w-auto bg-transparent p-0"
        onClick={toggleVisibility}
      />
      {hasPrivilegeToWriteProject && (
        <>
          <IconButton
            icon={isActive ? 'padlock-open' : 'padlock-locked'}
            title="Lock"
            className="h-auto w-auto bg-transparent p-0"
            onClick={() => toggleActiveLayer(!isActive)}
          />
          <LayerDrawerLayerContextMenu
            removeLayer={removeLayer}
            editLayer={editLayer}
            addImage={addImage}
            addText={addText}
          />
        </>
      )}
    </div>
  );
};
